@@ -4,7 +4,7 @@
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; URL: https://gitlab.com/protesilaos/logos
-;; Version: 0.2.0
+;; Version: 0.3.0
 ;; Package-Requires: ((emacs "27.1"))
 ;; Keywords: convenience, focus, writing, presentation, narrowing
 
@@ -166,11 +166,34 @@ This is only relevant when `logos-focus-mode' is enabled."
 
 (defun logos--narrow-to-page (count &optional back)
   "Narrow to COUNTth page with optional BACK motion."
+  ;; Position point to avoid skipping pages.
+  (when (and (buffer-narrowed-p)
+             (save-restriction
+               (widen)
+               (looking-at page-delimiter)))
+    (goto-char (if back
+                   (1+ (match-end 0))
+                 (1- (match-beginning 0)))))
   (if back
       (narrow-to-page (or (- count) -1))
     (narrow-to-page (or (abs count) 1)))
-  ;; Avoids the problem of skipping pages while cycling back and forth.
-  (goto-char (point-min)))
+  (let ((page-start (point-min-marker)))
+    ;; If outlines are pages, include match of page-delimiter in page
+    (when (and logos-outlines-are-pages
+               (save-excursion
+                 (goto-char (point-min))
+                 (save-restriction
+                   (widen)
+                   (looking-back page-delimiter (line-beginning-position)))))
+      (let ((match-start (match-beginning 0))
+            (page-end (point-max-marker)))
+        (widen)
+        (narrow-to-region match-start page-end)))
+    ;; Leave point at a standard location: if outlines are pages,
+    ;; leave it right after the page-delimiter (to match the
+    ;; unnarrowed behavior); if outlines are not pages, leave it at
+    ;; the beginning of the page.
+    (goto-char page-start)))
 
 (defvar logos-page-motion-hook nil
   "Hook that runs after a page motion.
@@ -236,8 +259,9 @@ page."
   "Return non-nil if there is a `page-delimiter' in the buffer.
 This function does not use `widen': it only checks the accessible
 portion of the buffer."
-  (or (save-excursion (re-search-forward page-delimiter nil t))
-      (save-excursion (re-search-backward page-delimiter nil t))))
+  (let ((delimiter (logos--page-delimiter)))
+    (or (save-excursion (re-search-forward delimiter nil t))
+        (save-excursion (re-search-backward delimiter nil t)))))
 
 (defun logos-narrow-visible-window ()
   "Narrow buffer to visible window area.
@@ -272,7 +296,10 @@ If narrowing is in effect, widen the view."
          (null (buffer-narrowed-p)))
     (narrow-to-region (region-beginning) (region-end)))
    ((logos--page-p)
-    (narrow-to-page))
+    ;; Use our own narrow to page function because when
+    ;; logos-outlines-are-pages is t, the page delimiter
+    ;; is included in the region narrowed to.
+    (logos--narrow-to-page 0))
    ((null (buffer-narrowed-p))
     (logos-narrow-visible-window))
    ((widen))))
@@ -306,7 +333,8 @@ alternate, thus toggling MODE."
   "Buffer-local mode for focused editing.
 When enabled it sets the buffer-local value of these user
 options: `logos-scroll-lock', `logos-variable-pitch',
-`logos-hide-mode-line'."
+`logos-hide-mode-line', `logos-indicate-buffer-boundaries',
+`logos-buffer-read-only', `logos-olivetti'."
   :init-value nil
   :global nil
   :lighter " Λ" ; lambda majuscule
